@@ -1,9 +1,9 @@
 /*
- *  $Id: fselect.c,v 1.114 2020/11/23 09:03:54 tom Exp $
+ *  $Id: fselect.c,v 1.118 2021/12/13 23:51:16 tom Exp $
  *
  *  fselect.c -- implements the file-selector box
  *
- *  Copyright 2000-2019,2020	Thomas E. Dickey
+ *  Copyright 2000-2020,2021	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -27,19 +27,19 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#if HAVE_DIRENT_H
+#if defined(HAVE_DIRENT_H)
 # include <dirent.h>
 # define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
 # define dirent direct
 # define NAMLEN(dirent) (dirent)->d_namlen
-# if HAVE_SYS_NDIR_H
+# if defined(HAVE_SYS_NDIR_H)
 #  include <sys/ndir.h>
 # endif
-# if HAVE_SYS_DIR_H
+# if defined(HAVE_SYS_DIR_H)
 #  include <sys/dir.h>
 # endif
-# if HAVE_NDIR_H
+# if defined(HAVE_NDIR_H)
 #  include <ndir.h>
 # endif
 #endif
@@ -408,6 +408,7 @@ complete(char *name, LIST * d_list, LIST * f_list, char **buff_ptr)
 
     match(name, d_list, f_list, &match_list);
     if (match_list.length == 0) {
+	free(match_list.data);
 	*buff_ptr = NULL;
 	return 0;
     }
@@ -424,6 +425,7 @@ complete(char *name, LIST * d_list, LIST * f_list, char **buff_ptr)
 	}
     } else {
 	int j;
+	char *next;
 
 	for (i = 0; i < test_len; i++) {
 	    char test_char = test[i];
@@ -439,7 +441,13 @@ complete(char *name, LIST * d_list, LIST * f_list, char **buff_ptr)
 	    } else
 		break;
 	}
-	buff = dlg_realloc(char, i + 1, buff);
+	next = dlg_realloc(char, i + 1, buff);
+	if (next == NULL) {
+	    free(buff);
+	    *buff_ptr = NULL;
+	    return 0;
+	}
+	buff = next;
     }
     free_match(&match_list);
     buff[i] = '\0';
@@ -644,6 +652,8 @@ dlg_fselect(const char *title, const char *path, int height, int width, int dsel
 #ifdef KEY_RESIZE
   retry:
 #endif
+    if (height > 0)
+	height += MIN_HIGH;
     dlg_auto_size(title, "", &height, &width, MIN_HIGH + min_items, min_wide);
 
     dlg_print_size(height, width);
