@@ -1,9 +1,9 @@
 /*
- *  $Id: help.c,v 1.2 2011/06/25 00:27:16 tom Exp $
+ *  $Id: help.c,v 1.3 2012/12/04 02:01:10 tom Exp $
  *
  *  help.c -- implements the help dialog
  *
- *  Copyright 2011	Thomas E. Dickey
+ *  Copyright 2011,2012	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -33,11 +33,22 @@ dialog_helpfile(const char *title,
 		int width)
 {
     int result = DLG_EXIT_ERROR;
+    DIALOG_VARS save;
 
     if (!dialog_vars.in_helpfile && file != 0 && *file != '\0') {
+	dlg_save_vars(&save);
+
+	dialog_vars.no_label = NULL;
+	dialog_vars.ok_label = NULL;
+	dialog_vars.help_button = FALSE;
+	dialog_vars.extra_button = FALSE;
+	dialog_vars.nook = FALSE;
+
 	dialog_vars.in_helpfile = TRUE;
+
 	result = dialog_textbox(title, file, height, width);
-	dialog_vars.in_helpfile = FALSE;
+
+	dlg_restore_vars(&save);
     }
     return (result);
 }
